@@ -1,11 +1,12 @@
 """Option parsing library for utilities."""
 __revision__ = '$Revision$'
 
-import ConfigParser
 import getopt
 import os
 import sys
 import Bcfg2.Client.Tools
+# Compatibility imports
+from Bcfg2.Bcfg2Py3k import ConfigParser
 
 def bool_cook(x):
     if x:
@@ -93,7 +94,7 @@ class Option(object):
 
     def parse(self, opts, rawopts):
         if self.cmd and opts:
-            # processing getopted data
+            # Processing getopted data
             optinfo = [opt[1] for opt in opts if opt[0] == self.cmd]
             if optinfo:
                 if optinfo[0]:
@@ -105,7 +106,7 @@ class Option(object):
             data = rawopts[rawopts.index(self.cmd) + 1]
             self.value = self.get_cooked_value(data)
             return
-        # no command line option found
+        # No command line option found
         if self.env and self.env in os.environ:
             self.value = self.get_cooked_value(os.environ[self.env])
             return
@@ -115,7 +116,7 @@ class Option(object):
                 return
             except:
                 pass
-        # default value not cooked
+        # Default value not cooked
         self.value = self.default
 
 class OptionSet(dict):
@@ -141,12 +142,13 @@ class OptionSet(dict):
         raise SystemExit(code)
 
     def parse(self, argv, do_getopt=True):
-        '''Parse options'''
+        '''Parse options from command line.'''
         if do_getopt:
             try:
                 opts, args = getopt.getopt(argv, self.buildGetopt(),
                                            self.buildLongGetopt())
-            except getopt.GetoptError, err:
+            except getopt.GetoptError:
+                err = sys.exc_info()[1]
                 self.helpExit(err)
             if '-h' in argv:
                 self.helpExit('', 0)
@@ -171,7 +173,19 @@ def colon_split(c_string):
         return c_string.split(':')
     return []
 
-#General options
+def get_bool(s):
+    # these values copied from ConfigParser.RawConfigParser.getboolean
+    # with the addition of True and False
+    truelist = ["1", "yes", "True", "true", "on"]
+    falselist = ["0", "no", "False", "false", "off"]
+    if s in truelist:
+        return True
+    elif s in falselist:
+        return False
+    else:
+        raise ValueError
+
+# General options
 CFILE = Option('Specify configuration file', DEFAULT_CONFIG_LOCATION, cmd='-C',
                odesc='<conffile>')
 LOCKFILE = Option('Specify lockfile',
@@ -187,10 +201,13 @@ INSTALL_PREFIX = Option('Installation location', cf=('server', 'prefix'),
                         default=DEFAULT_INSTALL_PREFIX, odesc='</path>')
 SENDMAIL_PATH = Option('Path to sendmail', cf=('reports', 'sendmailpath'),
                        default='/usr/lib/sendmail')
-INTERACTIVE = Option('prompt the user for each change', default=False,
+INTERACTIVE = Option('Run interactively, prompting the user for each change',
+                     default=False,
                      cmd='-I', )
-ENCODING = Option('Encoding of cfg files', default=sys.getdefaultencoding(),
-                  cmd='-E', odesc='<encoding>',
+ENCODING = Option('Encoding of cfg files',
+                  default='UTF-8',
+                  cmd='-E',
+                  odesc='<encoding>',
                   cf=('components', 'encoding'))
 PARANOID_PATH = Option('Specify path for paranoid file backups',
                        default='/var/cache/bcfg2', cf=('paranoid', 'path'),
@@ -201,8 +218,16 @@ PARANOID_MAX_COPIES = Option('Specify the number of paranoid copies you want',
 OMIT_LOCK_CHECK = Option('Omit lock check', default=False, cmd='-O')
 CORE_PROFILE = Option('profile',
                       default=False, cmd='-p', )
-                      
-#Metadata options
+FILES_ON_STDIN = Option('Operate on a list of files supplied on stdin',
+                        cmd='--stdin', default=False, long_arg=True)
+SCHEMA_PATH = Option('Path to XML Schema files', cmd='--schema',
+                     odesc='<schema path>',
+                     default="%s/share/bcfg2/schemas" % DEFAULT_INSTALL_PREFIX,
+                     long_arg=True)
+REQUIRE_SCHEMA = Option("Require property files to have matching schema files",
+                        cmd="--require-schema", default=False, long_arg=True)
+
+# Metadata options
 MDATA_OWNER = Option('Default Path owner',
                      default='root', cf=('mdata', 'owner'),
                      odesc='owner permissions')
@@ -218,15 +243,17 @@ MDATA_PERMS = Option('Default Path permissions',
 MDATA_PARANOID = Option('Default Path paranoid setting',
                      'false', cf=('mdata', 'paranoid'),
                      odesc='Path paranoid setting')
+MDATA_SENSITIVE = Option('Default Path sensitive setting',
+                     'false', cf=('mdata', 'sensitive'),
+                     odesc='Path sensitive setting')
 
-#Server options
+# Server options
 SERVER_REPOSITORY = Option('Server repository path', '/var/lib/bcfg2',
                            cf=('server', 'repository'), cmd='-Q',
                            odesc='<repository path>')
 SERVER_PLUGINS = Option('Server plugin list', cf=('server', 'plugins'),
                         # default server plugins
                         default=[
-                                 'Base',
                                  'Bundler',
                                  'Cfg',
                                  'Metadata',
@@ -239,6 +266,13 @@ SERVER_MCONNECT = Option('Server Metadata Connector list', cook=list_split,
                          cf=('server', 'connectors'), default=['Probes'], )
 SERVER_FILEMONITOR = Option('Server file monitor', cf=('server', 'filemonitor'),
                             default='default', odesc='File monitoring driver')
+SERVER_LISTEN_ALL = Option('Listen on all interfaces',
+                           cf=('server', 'listen_all'),
+                           cmd='--listen-all',
+                           default=False,
+                           long_arg=True,
+                           cook=get_bool,
+                           odesc='True|False')
 SERVER_LOCATION = Option('Server Location', cf=('components', 'bcfg2'),
                          default='https://localhost:6789', cmd='-S',
                          odesc='https://server:port')
@@ -255,7 +289,7 @@ SERVER_PASSWORD = Option('Communication Password', cmd='-x', odesc='<password>',
                          cf=('communication', 'password'), default=False)
 SERVER_PROTOCOL = Option('Server Protocol', cf=('communication', 'procotol'),
                          default='xmlrpc/ssl')
-#Client options
+# Client options
 CLIENT_KEY = Option('Path to SSL key', cf=('communication', 'key'),
                     default=None, cmd="--ssl-key", odesc='<ssl key>',
                     long_arg=True)
@@ -265,45 +299,54 @@ CLIENT_CERT = Option('Path to SSL certificate', default=None, cmd="--ssl-cert",
 CLIENT_CA = Option('Path to SSL CA Cert', default=None, cmd="--ca-cert",
                    cf=('communication', 'ca'), odesc='<ca cert>',
                    long_arg=True)
-CLIENT_SCNS = Option('list of server commonNames', default=None, cmd="--ssl-cns",
+CLIENT_SCNS = Option('List of server commonNames', default=None, cmd="--ssl-cns",
                      cf=('communication', 'serverCommonNames'),
                      odesc='<commonName1:commonName2>', cook=list_split,
                      long_arg=True)
-CLIENT_PROFILE = Option('assert the given profile for the host',
+CLIENT_PROFILE = Option('Assert the given profile for the host',
                         default=False, cmd='-p', odesc="<profile>")
-CLIENT_RETRIES = Option('the number of times to retry network communication',
+CLIENT_RETRIES = Option('The number of times to retry network communication',
                         default='3', cmd='-R', cf=('communication', 'retries'),
                         odesc="<retry count>")
-CLIENT_DRYRUN = Option('do not actually change the system',
+CLIENT_DRYRUN = Option('Do not actually change the system',
                        default=False, cmd='-n', )
 CLIENT_EXTRA_DISPLAY = Option('enable extra entry output',
                               default=False, cmd='-e', )
-CLIENT_PARANOID = Option('make automatic backups of config files',
-                         default=False, cmd='-P', cf=('client', 'paranoid'))
+CLIENT_PARANOID = Option('Make automatic backups of config files',
+                         default=False,
+                         cmd='-P',
+                         cook=get_bool,
+                         cf=('client', 'paranoid'))
 CLIENT_DRIVERS = Option('Specify tool driver set', cmd='-D',
                         cf=('client', 'drivers'),
                         odesc="<driver1,driver2>", cook=list_split,
                         default=Bcfg2.Client.Tools.default)
-CLIENT_CACHE = Option('store the configuration in a file',
+CLIENT_CACHE = Option('Store the configuration in a file',
                       default=False, cmd='-c', odesc="<cache path>")
-CLIENT_REMOVE = Option('force removal of additional configuration items',
+CLIENT_REMOVE = Option('Force removal of additional configuration items',
                        default=False, cmd='-r', odesc="<entry type|all>")
-CLIENT_BUNDLE = Option('only configure the given bundle(s)', default=[],
+CLIENT_BUNDLE = Option('Only configure the given bundle(s)', default=[],
                        cmd='-b', odesc='<bundle:bundle>', cook=colon_split)
-CLIENT_INDEP = Option('only configure the given bundle(s)', default=False,
+CLIENT_BUNDLEQUICK = Option('only verify/configure the given bundle(s)', default=False,
+                       cmd='-Q')
+CLIENT_INDEP = Option('Only configure independent entries, ignore bundles', default=False,
                        cmd='-z')
-CLIENT_KEVLAR = Option('run in kevlar (bulletproof) mode', default=False,
+CLIENT_KEVLAR = Option('Run in kevlar (bulletproof) mode', default=False,
                        cmd='-k', )
-CLIENT_DLIST = Option('run client in server decision list mode', default=False,
-                      cmd='-l', odesc='<whitelist|blacklist>')
-CLIENT_FILE = Option('configure from a file rather than querying the server',
+CLIENT_DLIST = Option('Run client in server decision list mode', default='none',
+                      cf=('client', 'decision'),
+                      cmd='-l', odesc='<whitelist|blacklist|none>')
+CLIENT_FILE = Option('Configure from a file rather than querying the server',
                      default=False, cmd='-f', odesc='<specification path>')
-CLIENT_QUICK = Option('disable some checksum verification', default=False,
+CLIENT_QUICK = Option('Disable some checksum verification', default=False,
                       cmd='-q', )
-CLIENT_USER = Option('the user to provide for authentication', default='root',
+CLIENT_USER = Option('The user to provide for authentication', default='root',
                      cmd='-u', cf=('communication', 'user'), odesc='<user>')
 CLIENT_SERVICE_MODE = Option('Set client service mode', default='default',
                              cmd='-s', odesc='<default|disabled|build>')
+CLIENT_TIMEOUT = Option('Set the client XML-RPC timeout', default=90,
+                        cmd='-t', cf=('communication', 'timeout'),
+                        odesc='<timeout>')
                      
 # APT client tool options
 CLIENT_APT_TOOLS_INSTALL_PATH = Option('Apt tools install path',
@@ -314,7 +357,7 @@ CLIENT_APT_TOOLS_VAR_PATH = Option('Apt tools var path',
 CLIENT_SYSTEM_ETC_PATH = Option('System etc path', cf=('APT', 'etc_path'),
                          default='/etc')
 
-#Logging options
+# Logging options
 LOGGING_FILE_PATH = Option('Set path of file log', default=None,
                            cmd='-o', odesc='<path>', cf=('logging', 'path'))
 
